Documentation
¶
Index ¶
- type Client
- func (c *Client) AuthPassword(collection, identity, password string, output any) error
- func (c *Client) Create(collection string, body any, output any, query ...Query) error
- func (c *Client) DELETE(path string, output any, query ...Query) error
- func (c *Client) Delete(collection, id string, output any, query ...Query) error
- func (c *Client) DisableAutoReauth() *Client
- func (c *Client) GET(path string, output any, query ...Query) error
- func (c *Client) List(collection string, output any, query ...Query) error
- func (c *Client) PATCH(path string, body any, output any, query ...Query) error
- func (c *Client) POST(path string, body any, output any, query ...Query) error
- func (c *Client) Raw(method, path string, body any, output any, query ...Query) error
- func (c *Client) RawCtx(ctx context.Context, method, path string, body any, output any, query ...Query) error
- func (c *Client) RawWithHeaders(ctx context.Context, method, path string, body any, output any, ...) error
- func (c *Client) Update(collection, id string, body any, output any, query ...Query) error
- func (c *Client) View(collection, id string, output any, query ...Query) error
- func (c *Client) WithToken(token string) *Client
- type Error
- type File
- type Headers
- type Query
- type Response
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
BaseURL string
HTTP *http.Client
Token string
// contains filtered or unexported fields
}
func (*Client) AuthPassword ¶
func (*Client) DisableAutoReauth ¶
func (*Client) RawWithHeaders ¶
Click to show internal directories.
Click to hide internal directories.